pub struct Line {
pub raw: String,
pub compare: Compare,
pub report: Option<Vec<Report>>,
}Expand description
A line of table dump generated by bgpdump from a MRT file.
Fields
raw: Stringcompare: CompareDesigned to be directly used.
report: Option<Vec<Report>>Slot used to store the generated report about this line.
Implementations